import React from 'react';
import { ColorBox } from 'devextreme-react/color-box';
import { getLocalization } from '@devexpress/analytics-core/property-grid/localization/_localization';
import { useDropDownOptions, useEditorOptions } from '../editorHooks';
const ColorPickerEditor = ({ data }) => {
    const colorBoxRef = React.useRef();
    const args = {
        getEditorOptions: () => ({
            value: data.displayValue,
            placeholder: getLocalization('(Not set)', 'ReportStringId.UD_PropertyGrid_NotSetText'),
            editAlphaChannel: true,
            disabled: data.disabled,
            inputAttr: { 'aria-label': data.displayName, id: data.editorInputId }
        })
    };
    const options = useEditorOptions(colorBoxRef, data, args);
    const dropDownOptions = useDropDownOptions(colorBoxRef, ({ element, container }) => {
        const dropDownOptions = {
            container,
            position: {
                at: 'left bottom',
                collision: 'flipfit flipfit',
                my: 'left top',
                boundary: container,
                of: element
            }
        };
        return dropDownOptions;
    });
    return (React.createElement(ColorBox, { ref: colorBoxRef, value: options.value, onValueChanged: options.onValueChanged, placeholder: options.placeholder, editAlphaChannel: options.editAlphaChannel, disabled: options.disabled, dropDownOptions: dropDownOptions, inputAttr: options.inputAttr }));
};
export default ColorPickerEditor;
