import React from 'react';
import Template from '../../../../core/Template';
import useDxForceRerender from '../../../../../hooks/dxForceRerender';
import { createDateRangeEditor } from 'devexpress-reporting/viewer/widgets/dateRange/dateRangeEditor';
import { ViewModelChangedEvent } from '@devexpress/analytics-core/serializer/native/viewModels/viewModelGenerator';
import useDxEllipsisEditor from '../../../../../hooks/dxEllipsisEditor';
const DateRangeWrapper = ({ data }) => {
    const dateRangeEditorRef = React.useRef();
    const [viewModel, setViewModel] = React.useState();
    const forceRerender = useDxForceRerender();
    data.visibilityChanged = forceRerender;
    React.useEffect(() => {
        const editor = createDateRangeEditor(data, dateRangeEditorRef.current, data);
        const vm = editor.getViewModel();
        const subscription = vm._viewModelEvents.on(ViewModelChangedEvent, forceRerender);
        vm.cacheElement(dateRangeEditorRef.current);
        setViewModel(vm);
        return () => {
            subscription && subscription();
            editor?.dispose();
        };
    }, []);
    return (React.createElement("div", { ref: dateRangeEditorRef, className: "dxrv-daterange-editor" }, viewModel && React.createElement(DateRange, { viewModel: viewModel })));
};
const DateRange = ({ viewModel }) => {
    const forceRerender = useDxForceRerender();
    const processClickEvent = () => {
        viewModel.showPopup();
        forceRerender();
    };
    const ellipsisEditorRef = useDxEllipsisEditor({
        buttonAction: processClickEvent,
        value: viewModel.displayValue,
        readOnly: true,
        disabled: viewModel.disabled,
        visible: viewModel.visible,
        openOnFieldClick: true,
        inputAttr: { 'aria-label': viewModel._displayName, id: viewModel._editorInputId }
    });
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { ref: ellipsisEditorRef }),
        React.createElement(Template, { template: viewModel.popupTemplate, data: viewModel.popupModel })));
};
export default DateRangeWrapper;
