import React from 'react';
import { TagBox } from 'devextreme-react/tag-box';
import Validator from 'devextreme-react/validator';
import { useDropDownOptions, useEditorOptions, useValidatorOptions } from '../../../../analytics/Properties/Editors/editorHooks';
const MultiValue = ({ data }) => {
    const tagBoxRef = React.useRef();
    const [value, setValue] = React.useState();
    const args = {
        getOptions: () => data.value.getOptions({
            dataSource: data.value.dataSource,
            searchEnabled: true,
            useItemTextAsTitle: true,
            searchExpr: data.value.searchExpr || ['displayValue'],
            value: data.value.value,
            displayExpr: data.value.displayExpr || 'displayValue',
            valueExpr: data.value.valueExpr || 'value',
            multiline: false,
            showSelectionControls: true,
            selectAllMode: 'allPages',
            inputAttr: { 'aria-label': data.value.displayName, id: data.value.editorInputId },
            disabled: data.value.disabled,
            selectAllText: data.value.selectAllText,
            placeholder: data.value.placeholder,
            maxDisplayedTags: data.value.maxDisplayedTags,
            showMultiTagOnly: true
        }),
    };
    const options = useEditorOptions(tagBoxRef, data, args);
    const dropDownOptions = useDropDownOptions(tagBoxRef, ({ element, container }) => ({
        container,
        position: {
            boundary: container,
            collision: 'flipfit', of: element, at: 'bottom', my: 'top'
        }
    }));
    const validatorOptions = useValidatorOptions(data);
    React.useEffect(() => {
        const model = data.getModel()?.value;
        if (value !== options.value) {
            setValue(options.value);
        }
        return model?.events.on('valueChanged', () => setValue(model.value));
    }, []);
    return (React.createElement(TagBox, { ref: tagBoxRef, dataSource: options.dataSource, searchEnabled: options.searchEnabled, useItemTextAsTitle: options.useItemTextAsTitle, searchExpr: options.searchExpr, value: value, displayExpr: options.displayExpr, valueExpr: options.valueExpr, multiline: options.multiline, showSelectionControls: options.showSelectionControls, onValueChanged: options.onValueChanged, onMultiTagPreparing: options.onMultiTagPreparing, inputAttr: options.inputAttr, disabled: options.disabled, selectAllText: options.selectAllText, placeholder: options.placeholder, maxDisplayedTags: options.maxDisplayedTags, showMultiTagOnly: options.showMultiTagOnly, dropDownOptions: dropDownOptions, selectAllMode: options.selectAllMode }, !!data.validationRules && React.createElement(Validator, { validationRules: validatorOptions.validationRules })));
};
export default MultiValue;
